@@ -35,6 +35,79 @@ from turberfield.dialogue.types import Stateful
 from turberfield.dialogue.types import Player
 
 
+class SceneTests(unittest.TestCase):
+
+    def test_one_scene(self):
+        content = textwrap.dedent(
+            """
+            Scene
+            =====
+
+            Shot
+            ----
+
+            Text
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        script.cast(script.select([]))
+        model = list(script.run())
+        shot, line = next(iter(model))
+        self.assertEqual("scene", shot.scene)
+        self.assertEqual("shot", shot.name)
+
+    def test_multi_scene(self):
+        content = textwrap.dedent(
+            """
+            Scene 1
+            =======
+
+            Shot 1
+            ------
+
+            Text
+
+            Scene 2
+            =======
+
+            Shot 2
+            ------
+
+            Text
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        script.cast(script.select([]))
+        model = list(script.run())
+        shot, line = next(iter(model))
+        self.assertEqual("scene 1", shot.scene)
+        self.assertEqual("shot 1", shot.name)
+
+    def test_duplicate_scene(self):
+        content = textwrap.dedent(
+            """
+            Scene 1
+            =======
+
+            Shot
+            ----
+
+            Text
+
+            Scene 2
+            =======
+
+            Shot
+            ----
+
+            Text
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        script.cast(script.select([]))
+        model = list(script.run())
+        shot, line = next(iter(model))
+        self.assertEqual("scene 1", shot.scene)
+        self.assertEqual("shot", shot.name)
+
+
 class PropertyDirectiveTests(unittest.TestCase):
 
     personae = [
